﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using PhoneBook.Classes;
using System.IO;
using System.Xml;
using System.Xml.Serialization;

namespace PhoneBook
{
    internal partial class FormPhoneBook : Form
    {

        ManageController controller;

        public FormPhoneBook()
        {
            InitializeComponent();
            controller = new ManageController(this);
        }

        public event EventHandler<AddPersonEventArgs> AddClicked;
        public event EventHandler<DeletePersonEventArgs> DeleteClicked;
        public event EventHandler<UpdatePersonEventArgs> UpdateClicked;


        public Person SelectedItem
        {
            get
            {
                if (listViewPeople.SelectedItems.Count > 0)
                    return listViewPeople.SelectedItems[0].Tag as Person;
                return null;
            }
        }

        private void buttonAddNewContact_Click(object sender, EventArgs e)
        {

            NewItemForm newForm = new NewItemForm(true);
            if (newForm.ShowDialog() == System.Windows.Forms.DialogResult.OK)
            {
                if (AddClicked != null)
                    AddClicked(this, new AddPersonEventArgs(newForm.ItemName, newForm.ItemPhone, newForm.ItemAddress, newForm.ItemEmail, newForm.ItemBirthday));
            }
        }

        private void buttonDeleteContact_Click(object sender, EventArgs e)
        {

        }

        private void buttonUpdateContact_Click(object sender, EventArgs e)
        {

        }

        public void UpdateView(List<Person> list)
        {

            listViewPeople.Items.Clear();
            foreach (var item in list)
            {
                ListViewItem lv_item = new ListViewItem(new string[] { item.Name, item.Phone, item.Email });
                listViewPeople.Items.Add(lv_item);
            }
        }

        private void buttonClearSearchTextBox_Click(object sender, EventArgs e)
        {
            textBoxSearch.Text = string.Empty;
        }

    }

    internal class AddPersonEventArgs : EventArgs
    {

        public AddPersonEventArgs(string name, string phone, string address, string email, DateTime birthday)
        {

            Name = name;
            Phone = phone;
            Address = address;
            Email = email;
            Birthday = birthday;
        }

        public string Name
        {
            get;
            private set;
        }

        public string Phone
        {
            get;
            private set;
        }

        public string Address
        {
            get;
            private set;
        }


        public string Email
        {
            get;
            private set;
        }

        public DateTime Birthday
        {
            get;
            private set;
        }
    }

    internal class DeletePersonEventArgs : EventArgs
    {

        public DeletePersonEventArgs(string name, string phone, string address, string email, DateTime birthday)
        {
            Name = name;
            Phone = phone;
            Address = address;
            Email = email;
            Birthday = birthday;
        }

        public string Name
        {
            get;
            private set;
        }

        public string Phone
        {
            get;
            private set;
        }

        public string Address
        {
            get;
            private set;
        }


        public string Email
        {
            get;
            private set;
        }

        public DateTime Birthday
        {
            get;
            private set;
        }
    }

    internal class UpdatePersonEventArgs : EventArgs
    {
        public UpdatePersonEventArgs(string name, string phone, string address, string email, DateTime birthday)
        {
            Name = name;
            Phone = phone;
            Address = address;
            Email = email;
            Birthday = birthday;
        }

        public string Name
        {
            get;
            private set;
        }

        public string Phone
        {
            get;
            private set;
        }

        public string Address
        {
            get;
            private set;
        }


        public string Email
        {
            get;
            private set;
        }

        public DateTime Birthday
        {
            get;
            private set;
        }
    }
}
